==> gtkhtml_1.0.2.orig.tar.gz: gtkhtml-1.0.2/components/html-editor/image.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* This file is part of the GtkHTML library

   Copyright (C) 2000 Helix Code, Inc.
   Authors:           Radek Doulik (rodo@helixcode.com)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHcANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _GTK_HTML_EDIT_IMAGE_H_
#define _GTK_HTML_EDIT_IMAGE_H_

#include <gnome.h>
#include "control-data.h"

GtkWidget          * image_properties              (GtkHTMLControlData *cd, gpointer *set_data);
GtkWidget          * image_insertion               (GtkHTMLControlData *cd, gpointer *set_data);
void                 image_apply_cb                (GtkHTMLControlData *cd, gpointer  get_data);
void                 image_insert_cb               (GtkHTMLControlData *cd, gpointer  get_data);
void                 image_close_cb                (GtkHTMLControlData *cd, gpointer  get_data);

#endif

==> gtkhtml-3.15.5.tar.gz: gtkhtml-3.15.5/components/html-editor/image.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* This file is part of the GtkHTML library

   Copyright (C) 2000 Helix Code, Inc.
   Authors:           Radek Doulik (rodo@helixcode.com)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHcANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _GTK_HTML_EDIT_IMAGE_H_
#define _GTK_HTML_EDIT_IMAGE_H_

#include <gtk/gtk.h>
#include "control-data.h"

GtkWidget          * image_properties              (GtkHTMLControlData *cd, gpointer *set_data);
GtkWidget          * image_insertion               (GtkHTMLControlData *cd, gpointer *set_data);
gboolean             image_apply_cb                (GtkHTMLControlData *cd, gpointer  get_data);
gboolean             image_insert_cb               (GtkHTMLControlData *cd, gpointer  get_data);
void                 image_close_cb                (GtkHTMLControlData *cd, gpointer  get_data);

#endif
